@@ -531,8 +531,8 @@ unpack() {
 	done
 	# Do not chmod '.' since it's probably ${WORKDIR} and PORTAGE_WORKDIR_MODE
 	# should be preserved.
-	find . -mindepth 1 '!' -type l '!' -perm /a+rX,u+w,g-w,o-w \
-		-exec chmod -f a+rX,u+w,g-w,o-w '{}' +
+	find . -mindepth 1 -maxdepth 1 ! -type l -print0 | \
+		${XARGS} -0 "${PORTAGE_BIN_PATH}/chmod-lite"
 }
 
 econf() {
