@@ -1,21 +1,21 @@
-# Copyright: 2005 Gentoo Foundation
+# Copyright 2005-2014 Gentoo Foundation
+# Distributed under the terms of the GNU General Public License v2
 # Author(s): Brian Harring (ferringb@gentoo.org)
-# License: GPL2
-# $Id: fs_template.py 15537 2010-03-02 19:50:48Z zmedico $
 
+import os as _os
 import sys
 from portage.cache import template
 from portage import os
 
 from portage.proxy.lazyimport import lazyimport
 lazyimport(globals(),
-	'portage.data:portage_gid',
 	'portage.exception:PortageException',
-	'portage.util:apply_permissions',
+	'portage.util:apply_permissions,ensure_dirs',
 )
 del lazyimport
 
 if sys.hexversion >= 0x3000000:
+	# pylint: disable=W0622
 	long = int
 
 class FsBased(template.database):
@@ -23,14 +23,11 @@ class FsBased(template.database):
 	attempt to ensure files have the specified owners/perms"""
 
 	def __init__(self, *args, **config):
-		"""throws InitializationError if needs args aren't specified
-		gid and perms aren't listed do to an oddity python currying mechanism
-		gid=portage_gid
-		perms=0665"""
 
 		for x, y in (("gid", -1), ("perms", -1)):
 			if x in config:
-				setattr(self, "_"+x, config[x])
+				# Since Python 3.4, chown requires int type (no proxies).
+				setattr(self, "_" + x, int(config[x]))
 				del config[x]
 			else:
 				setattr(self, "_"+x, y)
@@ -64,22 +61,27 @@ class FsBased(template.database):
 
 		for dir in path.lstrip(os.path.sep).rstrip(os.path.sep).split(os.path.sep):
 			base = os.path.join(base,dir)
-			if not os.path.exists(base):
-				if self._perms != -1:
-					um = os.umask(0)
-				try:
-					perms = self._perms
-					if perms == -1:
-						perms = 0
-					perms |= 0o755
-					os.mkdir(base, perms)
-					if self._gid != -1:
-						os.chown(base, -1, self._gid)
-				finally:
-					if self._perms != -1:
-						os.umask(um)
+			if ensure_dirs(base):
+				# We only call apply_permissions if ensure_dirs created
+				# a new directory, so as not to interfere with
+				# permissions of existing directories.
+				mode = self._perms
+				if mode == -1:
+					mode = 0
+				mode |= 0o755
+				apply_permissions(base, mode=mode, gid=self._gid)
+
+	def _prune_empty_dirs(self):
+		all_dirs = []
+		for parent, dirs, files in os.walk(self.location):
+			for x in dirs:
+				all_dirs.append(_os.path.join(parent, x))
+		while all_dirs:
+			try:
+				_os.rmdir(all_dirs.pop())
+			except OSError:
+				pass
 
-	
 def gen_label(base, label):
 	"""if supplied label is a path, generate a unique label based upon label, and supplied base path"""
 	if label.find(os.path.sep) == -1:
